
    import {
      compose,
      indexOf,
      head,
      isEmpty,
      length,
      not,
    } from 'ramda'

    import spected from 'spected'

    const colors = ['green', 'blue', 'red']
    const notEmpty = compose(not, isEmpty)
    const minLength = a => b => length(b) > a
    const hasPresetColors = x => indexOf(x, colors) !== -1

    // Messages

    const notEmptyMsg = field => `${field} should not be empty.`
    const minimumMsg = (field, len) => `Minimum ${field} length of ${len} is required.`

    const spec = {
      id: [[notEmpty, notEmptyMsg('id')]],
      userName: [[notEmpty, notEmptyMsg('userName')], [minLength(5), minimumMsg('UserName', 6)]],
      address: {
        street: [[notEmpty, notEmptyMsg('street')]],
      },
      settings: {
        profile: {
          design: {
            color: [[notEmpty, notEmptyMsg('color')], [hasPresetColors, 'Use defined colors']],
            background: [[notEmpty, notEmptyMsg('background')], [hasPresetColors, 'Use defined colors']],
          },
        },
      },
    }

    const input = {
      id: 1,
      userName: 'Random',
      address: {
        street: 'Foobar',
      },
      settings: {
        profile: {
          design: {
            color: 'green',
            background: 'blue',
          },
        },
      },
    }

    spected(spec, input)

    /* {
          id: true,
          userName: true,
          address: {
            street: true,
          },
          settings: {
            profile: {
              design: {
                color: true,
                background: true,
              },
            },
          },
        }
    */
